@@ -305,7 +305,7 @@ class ImageRecognition(object):
                 return regression_val, False
 
             else: 
-                if index == 1:
+                if index == self.classes[1]:
                     regression_val = [1.0]
                     return regression_val, False
 
@@ -372,6 +372,7 @@ class ImageRecognition(object):
                         tmp_x = tmp_x.astype(np.float32) / 255.
                         tmp_y, err = self.__prepare_output_val(index=i, key=file_list_by_class[i][idx[i]])
                         if err: 
+                            idx[i] += 1
                             continue
 
                         x_batch.append(tmp_x)
